@@ -29,6 +29,7 @@ import time
 
 from .. import Service
 from ...uuid import StandardUUID
+from ...characteristics import Characteristic
 from ...characteristics.string import StringCharacteristic
 from ...characteristics import StructCharacteristic
 from ...characteristics.int import Uint8Characteristic
@@ -69,7 +70,11 @@ class BatteryService(Service):
     """Provides battery level information"""
 
     uuid = StandardUUID(0x180F)
-    level = Uint8Characteristic(max_value=100, uuid=StandardUUID(0x2A19))
+    level = Uint8Characteristic(
+        max_value=100,
+        properties=Characteristic.READ | Characteristic.NOTIFY,
+        uuid=StandardUUID(0x2A19),
+    )
 
 
 class CurrentTimeService(Service):
